@@ -33,7 +33,7 @@ JSON::Util - easy and portable encode/decode of JSON
 use warnings;
 use strict;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use 5.010;
 use feature 'state';
@@ -41,7 +41,7 @@ use feature 'state';
 use Scalar::Util 'blessed';
 use IO::Any;
 use Carp 'croak';
-use JSON::XS;
+use JSON::MaybeXS;
 
 =head1 METHODS
 
@@ -49,7 +49,7 @@ use JSON::XS;
 
 Object constructor. Needed only when the L</default_json> configuration
 needs to be changed. Any key/value passed as parameter will be called on
-C<<JSON::XS->new()>> as C<<$json->$key($value)>>.
+C<<JSON::MaybeXS->new()>> as C<<$json->$key($value)>>.
 
 =cut
 
@@ -64,7 +64,7 @@ sub new {
 
     my $self  = bless \%options, __PACKAGE__;
     
-    my $json = JSON::XS->new();
+    my $json = JSON::MaybeXS->new();
     while (my ($option, $value) = each %options) {
         $json->$option($value);
     }
@@ -76,7 +76,7 @@ sub new {
 
 =head2 default_json
 
-Returns C<<JSON::XS->new()>> with:
+Returns C<<JSON::MaybeXS->new()>> with:
 
         'utf8'            => 1,
         'pretty'          => 1,
@@ -92,7 +92,7 @@ sub default_json {
 
 =head2 json
 
-Returns current L<JSON::XS> object.
+Returns current L<JSON::MaybeXS> object.
 
 =cut
 
@@ -123,7 +123,7 @@ sub decode {
 
 =head2 encode($data, [$where], [$opt])
 
-Returns encoded C<$data>. If C<$where> is passed then then the result is
+Returns encoded C<$data>. If C<$where> is passed then the result is
 written there. See L<IO::Any> for C<$where> and C<$opt> description.
 
 =cut
@@ -194,6 +194,12 @@ L<http://search.cpan.org/dist/JSON-Util>
 
 =head1 ACKNOWLEDGEMENTS
 
+The following people have contributed to the Sys::Path by committing their
+code, sending patches, reporting bugs, asking questions, suggesting useful
+advises, nitpicking, chatting on IRC or commenting on my blog (in no particular
+order):
+
+    John SJ Anderson
 
 =head1 COPYRIGHT & LICENSE
 
